@@ -1193,11 +1193,12 @@ class Askdata(SignUp):
         if (workspace == ''):
             if ('/' in dataset):
                 workspace = dataset.split("/")[0]
-                dataset_slug = dataset.split("/")[1]
+                dataset = dataset.split("/")[1]
+
 
 
         agent = self.agent(slug=workspace)
-        return agent.query(dataset_slug, fields, filters, sorted_by, limit=limit, offset=offset, pivot=pivot)
+        return agent.query(dataset, fields, filters, sorted_by, limit=limit, offset=offset, pivot=pivot)
 
 
     def get(self, query, workspace='', dataset='', lang="en", fields:list=[], filters=None, sorted_by=None, get_raw_data=False):
